@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.translate_v3.types import translation_service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import TranslationServiceTransport, DEFAULT_CLIENT_INFO
 
 
@@ -52,7 +49,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
         self,
         *,
         host: str = "translate.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -62,11 +59,13 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -101,6 +100,8 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
           google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -154,6 +155,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -177,7 +179,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
     def create_channel(
         cls,
         host: str = "translate.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -208,13 +210,15 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -330,7 +334,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
     def batch_translate_text(
         self,
     ) -> Callable[
-        [translation_service.BatchTranslateTextRequest], operations.Operation
+        [translation_service.BatchTranslateTextRequest], operations_pb2.Operation
     ]:
         r"""Return a callable for the batch translate text method over gRPC.
 
@@ -358,14 +362,16 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
             self._stubs["batch_translate_text"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3.TranslationService/BatchTranslateText",
                 request_serializer=translation_service.BatchTranslateTextRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_translate_text"]
 
     @property
     def create_glossary(
         self,
-    ) -> Callable[[translation_service.CreateGlossaryRequest], operations.Operation]:
+    ) -> Callable[
+        [translation_service.CreateGlossaryRequest], operations_pb2.Operation
+    ]:
         r"""Return a callable for the create glossary method over gRPC.
 
         Creates a glossary and returns the long-running operation.
@@ -385,7 +391,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
             self._stubs["create_glossary"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3.TranslationService/CreateGlossary",
                 request_serializer=translation_service.CreateGlossaryRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_glossary"]
 
@@ -451,7 +457,9 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
     @property
     def delete_glossary(
         self,
-    ) -> Callable[[translation_service.DeleteGlossaryRequest], operations.Operation]:
+    ) -> Callable[
+        [translation_service.DeleteGlossaryRequest], operations_pb2.Operation
+    ]:
         r"""Return a callable for the delete glossary method over gRPC.
 
         Deletes a glossary, or cancels glossary construction if the
@@ -472,7 +480,7 @@ class TranslationServiceGrpcTransport(TranslationServiceTransport):
             self._stubs["delete_glossary"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3.TranslationService/DeleteGlossary",
                 request_serializer=translation_service.DeleteGlossaryRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_glossary"]
 
